@@ -139,49 +139,3 @@ class Dict(Key, collections.MutableMapping):
             return self._client.hlen(self.name)
         except redispy_exception.ResponseError:
             raise TypeError
-
-    def incr(self, key, increment=DEFAULT_INCREMENT):
-        """ 将dict[key]中的值加上increment。
-        dict[key]中储存的必须是整数值(int)，否则引发异常。
-
-        Args:
-            key: 键
-            increment：增量
-
-        Time:
-            O(1)
-
-        Returns:
-            int: 执行incr操作之后，dict[key]的值
-
-        Raises:
-            KeyError:如果dict[key]存在但储存的不是整数类型时抛出。
-            TypeError: Key对象不是Dict类型时抛出。
-        """
-        if self.exists and self._represent != REDIS_TYPE['hash']:
-            raise TypeError
-
-        try:
-            return self._client.hincrby(self.name, key, increment)
-        except redispy_exception.ResponseError:
-            raise KeyError
-
-    def decr(self, key, decrement=DEFAULT_DECREMENT):
-        """ 将dict[key]中的值减去decrement。
-        dict[key]中储存的必须是整数值(int)，否则引发异常。
-
-        Args:
-            key: 键
-            decrement：减量
-
-        Time:
-            O(1)
-
-        Returns:
-            int: 执行decr操作之后，dict[key]的值
-
-        Raises:
-            KeyError:如果dict[key]存在且储存的不是整数类型时抛出。
-            TypeError: Key对象不是Dict类型时抛出。
-        """
-        return self.incr(key, 0-decrement)
